<?php
/**
 * Jester functions and definitions
 *
 * @package Jester
 */

if ( ! function_exists( 'jester_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function jester_setup() {
  /**
   * Set the content width based on the theme's design and stylesheet.
   */
  if ( ! isset( $content_width ) ) {
	  $content_width = 640; /* pixels */
  }
  
	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on Jester, use a find and replace
	 * to change 'jester' to the name of your theme in all the template files
	 */
	load_theme_textdomain( 'jester', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link http://codex.wordpress.org/Function_Reference/add_theme_support#Post_Thumbnails
	 */
	//add_theme_support( 'post-thumbnails' );

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'primary' => __( 'Primary Menu', 'jester' ),
		'social' => __( 'Social Media Menu', 'jester' )
	) );

  // Enable support for featured images
  add_theme_support( "post-thumbnails" );
    
	// Enable support for Post Formats.
	add_theme_support( 'post-formats', array( 'aside', 'image', 'video', 'quote', 'link' ) );

	// Enable support for HTML5 markup.
	add_theme_support( 'html5', array(
		'comment-list',
		'search-form',
		'comment-form',
		'gallery',
	) );
}
endif; // jester_setup
add_action( 'after_setup_theme', 'jester_setup' );

/**
 * Register widgetized area and update sidebar with default widgets.
 */
function jester_widgets_init() {
	register_sidebar( array(
		'name'          => __( 'Sidebar', 'jester' ),
		'id'            => 'sidebar-1',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
}
add_action( 'widgets_init', 'jester_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function jester_scripts() {
    wp_enqueue_style( 'jester-google-fonts', '//fonts.googleapis.com/css?family=Sansita+One|Kameron' );
    
    wp_enqueue_style( 'jester-genericons', get_template_directory_uri() . '/inc/genericons/genericons.css' );
    
	wp_enqueue_style( 'jester-style', get_stylesheet_uri() );

	wp_enqueue_script( 'jester-header-toggles', get_template_directory_uri() . '/inc/js/toggles.js', array( 'jquery' ), null, true );
	
	wp_enqueue_script( 'jester-skip-link-focus-fix', get_template_directory_uri() . '/inc/js/skip-link-focus-fix.js', array(), '20130115', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'jester_scripts' );

if ( ! function_exists( 'jester_extra_options' ) ) :
/**
 * Add theme options to the Customizer
 */
function jester_extra_options( $wp_customize ) {
    $wp_customize->add_section( 'je_footer_text', array(
        'title'       => __( 'Footer Text', 'jester' ),
        'description' => __( 'Text entered in this form will appear in the footer in place of the default text. A limited amount of HTML may be used.', 'jester' ),
        'priority'    => 35
    ) );
    
    $wp_customize->add_setting( 'jester_theme_options[footer_text]', array(
        'default'           => '',
        'type'              => 'option',
        'capability'        => 'edit_theme_options',
        'sanitize_callback' => 'wp_kses'
    ) );
    
    $wp_customize->add_control( 'jester_theme_options[footer_text]', array(
        'label'    => __( 'Footer Text', 'jester' ),
        'section'  => 'je_footer_text',
        'settings' => 'jester_theme_options[footer_text]',
        'type'     => 'text'
    ) );
}
endif;
add_action( 'customize_register', 'jester_extra_options' );

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/inc/jetpack.php';