<?php
/**
 * Custom template tags for this theme.
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package Jester
 */

if ( ! function_exists( 'jester_paging_nav' ) ) :
/**
 * Display navigation to next/previous set of posts when applicable.
 *
 * @return void
 */
function jester_paging_nav() {
	// Don't print empty markup if there's only one page.
	if ( $GLOBALS['wp_query']->max_num_pages < 2 ) {
		return;
	}
	?>
	
	<hr />
	
	<nav class="navigation paging-navigation" role="navigation">
		<h1 class="screen-reader-text"><?php _e( 'Posts navigation', 'jester' ); ?></h1>
		<div class="nav-links">

			<?php if ( get_next_posts_link() ) : ?>
			<div class="nav-previous"><?php next_posts_link( __( '<span class="meta-nav">&larr;</span> Older posts', 'jester' ) ); ?></div>
			<?php endif; ?>

			<?php if ( get_previous_posts_link() ) : ?>
			<div class="nav-next"><?php previous_posts_link( __( 'Newer posts <span class="meta-nav">&rarr;</span>', 'jester' ) ); ?></div>
			<?php endif; ?>

		</div><!-- .nav-links -->
	</nav><!-- .navigation -->
	<?php
}
endif;

if ( ! function_exists( 'jester_post_nav' ) ) :
/**
 * Display navigation to next/previous post when applicable.
 *
 * @return void
 */
function jester_post_nav() {
	// Don't print empty markup if there's nowhere to navigate.
	$previous = ( is_attachment() ) ? get_post( get_post()->post_parent ) : get_adjacent_post( false, '', true );
	$next     = get_adjacent_post( false, '', false );

	if ( ! $next && ! $previous ) {
		return;
	}
	?>
	
	<hr />
	
	<nav class="navigation post-navigation" role="navigation">
		<h1 class="screen-reader-text"><?php _e( 'Post navigation', 'jester' ); ?></h1>
		<div class="nav-links">
			<?php
				previous_post_link( '<div class="nav-previous">%link</div>', _x( '<span class="meta-nav">&larr;</span> %title', 'Previous post link', 'jester' ) );
				next_post_link(     '<div class="nav-next">%link</div>',     _x( '%title <span class="meta-nav">&rarr;</span>', 'Next post link',     'jester' ) );
			?>
		</div><!-- .nav-links -->
	</nav><!-- .navigation -->
	<?php
}
endif;

if ( ! function_exists( 'jester_entry_meta' ) ) :
/**
 * Prints HTML with all meta information: post date, author, tags, etc.
 */
function jester_entry_meta() {
  global $post;
    
  if ( wp_attachment_is_image() && 'attachment' == $post->post_type ) :
    $attachment_metadata = wp_get_attachment_metadata( $post->ID );
    printf( __( '<li class="zoom meta-text"><a href="%1$s">See full-size image: (%2$s x %3$s)</span></li>', 'jester' ),
      esc_html( wp_get_attachment_url( $post->ID ) ),
      $attachment_metadata[ 'height' ],
      $attachment_metadata[ 'width' ]
    );
  endif;
    
  $time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time>';
    
	if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
		$time_string .= '<time class="updated" datetime="%3$s">%4$s</time>';
	}

	$time_string = sprintf( $time_string,
		esc_attr( get_the_date( 'c' ) ),
		esc_html( get_the_date() ),
		esc_attr( get_the_modified_date( 'c' ) ),
		esc_html( get_the_modified_date() )
	);

  printf( __( '<li class="posted-on meta-text">Date: %s</li>', 'jester' ),
    sprintf( '<a href="%1$s" rel="bookmark">%2$s</a>',
      esc_url( get_permalink() ),
      $time_string
    )
  );
    
  printf( __( '<li class="author vcard meta-text">Author: <a class="url fn n" href="%1$s">%2$s</a></li>', 'jester' ),
    esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ),
    esc_html( get_the_author() )
  );
    
  /* translators: used between list items, there is a space after the comma */
  $categories_list = get_the_category_list( __( ', ', 'jester' ) );
  if ( $categories_list && jester_categorized_blog() ) :
    printf( __( '<li class="cat-links meta-text">Posted In: %s</li>', 'jester' ),
      $categories_list
    );
  endif;
    
  /* translators: used between list items, there is a space after the comma */
  $tags_list = get_the_tag_list( '', __( ', ', 'jester' ) );
  if ( $tags_list ) :
    printf( __( '<li class="tags-links meta-text">Tagged: %s</li>', 'jester' ),
      $tags_list
    );
  endif;
    
  if ( ! is_single() && ! post_password_required() && ( comments_open() || '0' != get_comments_number() ) ) :
    echo '<li class="comments-link meta-text">';
    comments_popup_link( __( 'Leave a comment', 'jester' ), __( '1 Comment', 'jester' ), __( '% Comments', 'jester' ) );
    echo '</li>';
  endif;
    
  edit_post_link( __( 'Edit', 'jester' ), '<li class="edit-link meta-text">', '</li>' );
}
endif;

/**
 * Returns true if a blog has more than 1 category.
 */
function jester_categorized_blog() {
	if ( false === ( $all_the_cool_cats = get_transient( 'all_the_cool_cats' ) ) ) {
		// Create an array of all the categories that are attached to posts.
		$all_the_cool_cats = get_categories( array(
			'hide_empty' => 1,
		) );

		// Count the number of categories that are attached to the posts.
		$all_the_cool_cats = count( $all_the_cool_cats );

		set_transient( 'all_the_cool_cats', $all_the_cool_cats );
	}

	if ( '1' != $all_the_cool_cats ) {
		// This blog has more than 1 category so jester_categorized_blog should return true.
		return true;
	} else {
		// This blog has only 1 category so jester_categorized_blog should return false.
		return false;
	}
}

/**
 * Flush out the transients used in jester_categorized_blog.
 */
function jester_category_transient_flusher() {
	// Like, beat it. Dig?
	delete_transient( 'all_the_cool_cats' );
}
add_action( 'edit_category', 'jester_category_transient_flusher' );
add_action( 'save_post',     'jester_category_transient_flusher' );

/**
 * Custom function to list comments
 */
if ( ! function_exists( 'jester_list_comments' ) ) :
function jester_list_comments( $comment, $args, $depth ) {
  $GLOBALS['comment'] = $comment;
	global $post;
	
	if ( 'pingback' == $comment->comment_type || 'trackback' == $comment->comment_type ) : ?>
		<li id="div-comment-<?php comment_ID(); ?>" <?php comment_class(); ?>>
			<article class="comment-body">
				<header class="comment-meta">
					<cite><?php _e( 'Pingback:', 'jester' ); ?></cite>
				
					<?php edit_comment_link( __( 'Edit', 'jester' ) ); ?>
				</header>
				
				<section class="pingback-content">
					<?php comment_author_link(); ?>
				</section>
			</article><!-- .comment-body -->
		</li><!-- #comment-id -->
	<?php else : ?>
		<li <?php comment_class( empty( $args['has_children'] ) ? '' : 'parent' ); ?>>
		  <article id="comment-<?php comment_ID(); ?>" class="comment-body">
		    <header class="comment-header">
		      <?php
		      if ( '0' != $args['avatar_size'] ) :
		        echo get_avatar( $comment, $args['avatar_size'] );
            endif;
          ?>
                    
          <cite class="fn"><?php echo get_comment_author_link(); ?></cite>
		    </header>
		        
        <div class="comment-content">
		      <?php
		      if ( '0' == $comment->comment_approved ) : ?>
		        <p><?php _e( 'Your comment is awaiting moderation.', 'jester' ); ?></p>
          <?php endif; ?>
                
		      <p><?php comment_text(); ?></p>
		    </div>
		    
		    <footer class="comment-meta">
		      <ul>    
		          <li class="comment-posted-on meta-text"><a href="<?php echo esc_url( get_comment_link( $comment->comment_ID ) ); ?>"><time datetime="<?php comment_time( 'c' ); ?>"><?php printf( _x( '%1$s, %2$s', '1: date, 2: time', 'jester' ), get_comment_date() /* %1$s */, get_comment_time() /* %2$s */ ); ?></time></a></li>
		          
                <?php edit_comment_link( __( 'Edit', 'jester' ), '<li class="comment-edit-link meta-text">', '</li>' ); ?>
                
                <?php
                comment_reply_link( array_merge( $args, array(
                  'add_below' => 'comment',
                  'depth'     => $depth,
                  'max_depth' => $args['max_depth'],
                  'before'    => '<li class="comment-reply-link meta-text">',
                  'after'     => '</li>'
                ) ) );
                ?>
		      </ul>
		    </footer>
		  </article>
		</li>
  <?php endif; ?>
<?php
}
endif; // ends check for jester_list_comments()
?>